mocks

package
v0.0.0-...-5285ae3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package mocks is a generated GoMock package.

Package mocks is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockKeyringClient

type MockKeyringClient struct {
	// contains filtered or unexported fields
}

MockKeyringClient is a mock of KeyringClient interface.

func NewMockKeyringClient

func NewMockKeyringClient(ctrl *gomock.Controller) *MockKeyringClient

NewMockKeyringClient creates a new mock instance.

func (*MockKeyringClient) Delete

func (m *MockKeyringClient) Delete(service, user string) error

Delete mocks base method.

func (*MockKeyringClient) DeleteAll

func (m *MockKeyringClient) DeleteAll(service string) error

DeleteAll mocks base method.

func (*MockKeyringClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockKeyringClient) Get

func (m *MockKeyringClient) Get(service, user string) (string, error)

Get mocks base method.

func (*MockKeyringClient) Set

func (m *MockKeyringClient) Set(service, user, password string) error

Set mocks base method.

type MockKeyringClientMockRecorder

type MockKeyringClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockKeyringClientMockRecorder is the mock recorder for MockKeyringClient.

func (*MockKeyringClientMockRecorder) Delete

func (mr *MockKeyringClientMockRecorder) Delete(service, user any) *gomock.Call

Delete indicates an expected call of Delete.

func (*MockKeyringClientMockRecorder) DeleteAll

func (mr *MockKeyringClientMockRecorder) DeleteAll(service any) *gomock.Call

DeleteAll indicates an expected call of DeleteAll.

func (*MockKeyringClientMockRecorder) Get

func (mr *MockKeyringClientMockRecorder) Get(service, user any) *gomock.Call

Get indicates an expected call of Get.

func (*MockKeyringClientMockRecorder) Set

func (mr *MockKeyringClientMockRecorder) Set(service, user, password any) *gomock.Call

Set indicates an expected call of Set.

type MockSecureStore

type MockSecureStore struct {
	// contains filtered or unexported fields
}

MockSecureStore is a mock of SecureStore interface.

func NewMockSecureStore

func NewMockSecureStore(ctrl *gomock.Controller) *MockSecureStore

NewMockSecureStore creates a new mock instance.

func (*MockSecureStore) Available

func (m *MockSecureStore) Available() bool

Available mocks base method.

func (*MockSecureStore) DeleteKey

func (m *MockSecureStore) DeleteKey(profileName, propertyName string)

DeleteKey mocks base method.

func (*MockSecureStore) DeleteProfile

func (m *MockSecureStore) DeleteProfile(profileName string)

DeleteProfile mocks base method.

func (*MockSecureStore) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockSecureStore) Get

func (m *MockSecureStore) Get(profileName, propertyName string) string

Get mocks base method.

func (*MockSecureStore) Save

func (m *MockSecureStore) Save() error

Save mocks base method.

func (*MockSecureStore) Set

func (m *MockSecureStore) Set(profileName, propertyName, value string)

Set mocks base method.

type MockSecureStoreMockRecorder

type MockSecureStoreMockRecorder struct {
	// contains filtered or unexported fields
}

MockSecureStoreMockRecorder is the mock recorder for MockSecureStore.

func (*MockSecureStoreMockRecorder) Available

func (mr *MockSecureStoreMockRecorder) Available() *gomock.Call

Available indicates an expected call of Available.

func (*MockSecureStoreMockRecorder) DeleteKey

func (mr *MockSecureStoreMockRecorder) DeleteKey(profileName, propertyName any) *gomock.Call

DeleteKey indicates an expected call of DeleteKey.

func (*MockSecureStoreMockRecorder) DeleteProfile

func (mr *MockSecureStoreMockRecorder) DeleteProfile(profileName any) *gomock.Call

DeleteProfile indicates an expected call of DeleteProfile.

func (*MockSecureStoreMockRecorder) Get

func (mr *MockSecureStoreMockRecorder) Get(profileName, propertyName any) *gomock.Call

Get indicates an expected call of Get.

func (*MockSecureStoreMockRecorder) Save

Save indicates an expected call of Save.

func (*MockSecureStoreMockRecorder) Set

func (mr *MockSecureStoreMockRecorder) Set(profileName, propertyName, value any) *gomock.Call

Set indicates an expected call of Set.

type MockStore

type MockStore struct {
	// contains filtered or unexported fields
}

MockStore is a mock of Store interface.

func NewMockStore

func NewMockStore(ctrl *gomock.Controller) *MockStore

NewMockStore creates a new mock instance.

func (*MockStore) DeleteProfile

func (m *MockStore) DeleteProfile(profileName string) error

DeleteProfile mocks base method.

func (*MockStore) EXPECT

func (m *MockStore) EXPECT() *MockStoreMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockStore) GetGlobalValue

func (m *MockStore) GetGlobalValue(propertyName string) any

GetGlobalValue mocks base method.

func (*MockStore) GetHierarchicalValue

func (m *MockStore) GetHierarchicalValue(profileName, propertyName string) any

GetHierarchicalValue mocks base method.

func (*MockStore) GetProfileNames

func (m *MockStore) GetProfileNames() []string

GetProfileNames mocks base method.

func (*MockStore) GetProfileStringMap

func (m *MockStore) GetProfileStringMap(profileName string) map[string]string

GetProfileStringMap mocks base method.

func (*MockStore) GetProfileValue

func (m *MockStore) GetProfileValue(profileName, propertyName string) any

GetProfileValue mocks base method.

func (*MockStore) IsSecure

func (m *MockStore) IsSecure() bool

IsSecure mocks base method.

func (*MockStore) IsSetGlobal

func (m *MockStore) IsSetGlobal(propertyName string) bool

IsSetGlobal mocks base method.

func (*MockStore) RenameProfile

func (m *MockStore) RenameProfile(oldProfileName, newProfileName string) error

RenameProfile mocks base method.

func (*MockStore) Save

func (m *MockStore) Save() error

Save mocks base method.

func (*MockStore) SetGlobalValue

func (m *MockStore) SetGlobalValue(propertyName string, value any)

SetGlobalValue mocks base method.

func (*MockStore) SetProfileValue

func (m *MockStore) SetProfileValue(profileName, propertyName string, value any)

SetProfileValue mocks base method.

type MockStoreMockRecorder

type MockStoreMockRecorder struct {
	// contains filtered or unexported fields
}

MockStoreMockRecorder is the mock recorder for MockStore.

func (*MockStoreMockRecorder) DeleteProfile

func (mr *MockStoreMockRecorder) DeleteProfile(profileName any) *gomock.Call

DeleteProfile indicates an expected call of DeleteProfile.

func (*MockStoreMockRecorder) GetGlobalValue

func (mr *MockStoreMockRecorder) GetGlobalValue(propertyName any) *gomock.Call

GetGlobalValue indicates an expected call of GetGlobalValue.

func (*MockStoreMockRecorder) GetHierarchicalValue

func (mr *MockStoreMockRecorder) GetHierarchicalValue(profileName, propertyName any) *gomock.Call

GetHierarchicalValue indicates an expected call of GetHierarchicalValue.

func (*MockStoreMockRecorder) GetProfileNames

func (mr *MockStoreMockRecorder) GetProfileNames() *gomock.Call

GetProfileNames indicates an expected call of GetProfileNames.

func (*MockStoreMockRecorder) GetProfileStringMap

func (mr *MockStoreMockRecorder) GetProfileStringMap(profileName any) *gomock.Call

GetProfileStringMap indicates an expected call of GetProfileStringMap.

func (*MockStoreMockRecorder) GetProfileValue

func (mr *MockStoreMockRecorder) GetProfileValue(profileName, propertyName any) *gomock.Call

GetProfileValue indicates an expected call of GetProfileValue.

func (*MockStoreMockRecorder) IsSecure

func (mr *MockStoreMockRecorder) IsSecure() *gomock.Call

IsSecure indicates an expected call of IsSecure.

func (*MockStoreMockRecorder) IsSetGlobal

func (mr *MockStoreMockRecorder) IsSetGlobal(propertyName any) *gomock.Call

IsSetGlobal indicates an expected call of IsSetGlobal.

func (*MockStoreMockRecorder) RenameProfile

func (mr *MockStoreMockRecorder) RenameProfile(oldProfileName, newProfileName any) *gomock.Call

RenameProfile indicates an expected call of RenameProfile.

func (*MockStoreMockRecorder) Save

func (mr *MockStoreMockRecorder) Save() *gomock.Call

Save indicates an expected call of Save.

func (*MockStoreMockRecorder) SetGlobalValue

func (mr *MockStoreMockRecorder) SetGlobalValue(propertyName, value any) *gomock.Call

SetGlobalValue indicates an expected call of SetGlobalValue.

func (*MockStoreMockRecorder) SetProfileValue

func (mr *MockStoreMockRecorder) SetProfileValue(profileName, propertyName, value any) *gomock.Call

SetProfileValue indicates an expected call of SetProfileValue.

Jump to